@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Sequence
+from collections.abc import Sequence
 
 from pre_commit import lang_base
 from pre_commit.prefix import Prefix
